@@ -21,16 +21,16 @@
 #include <QApplication>
 #include <QComboBox>
 #include <QDialogButtonBox>
-#include <QGroupBox>
-#include <QLayout>
-#include <QLabel>
-#include <QTimer>
-#include <QRadioButton>
 #include <QFileInfo>
-#include <QProgressBar>
+#include <QGroupBox>
+#include <QLabel>
+#include <QLayout>
 #include <QPainter>
+#include <QProgressBar>
+#include <QRadioButton>
 #include <QScrollBar>
 #include <QStandardPaths>
+#include <QTimer>
 
 /**
  * Qt allocates very little horizontal space for the icon name,
@@ -42,9 +42,12 @@ class KIconCanvasDelegate : public QAbstractItemDelegate
     Q_OBJECT
 public:
     KIconCanvasDelegate(KIconCanvas *parent, QAbstractItemDelegate *defaultDelegate);
-    ~KIconCanvasDelegate() override {}
+    ~KIconCanvasDelegate() override
+    {
+    }
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+
 private:
     KIconCanvas *m_iconCanvas = nullptr;
     QAbstractItemDelegate *m_defaultDelegate = nullptr;
@@ -82,18 +85,17 @@ QSize KIconCanvasDelegate::sizeHint(const QStyleOptionViewItem &option, const QM
  */
 
 KIconCanvas::KIconCanvas(QWidget *parent)
-    : QListWidget(parent),
-      m_loading(false),
-      m_timer(new QTimer(this)),
-      m_delegate(new KIconCanvasDelegate(this, itemDelegate()))
+    : QListWidget(parent)
+    , m_loading(false)
+    , m_timer(new QTimer(this))
+    , m_delegate(new KIconCanvasDelegate(this, itemDelegate()))
 {
     setViewMode(IconMode);
     setUniformItemSizes(true);
     setMovement(Static);
     setIconSize(QSize(60, 60));
     connect(m_timer, &QTimer::timeout, this, QOverload<>::of(&KIconCanvas::loadFiles));
-    connect(this, &QListWidget::currentItemChanged,
-            this, &KIconCanvas::currentListItemChanged);
+    connect(this, &QListWidget::currentItemChanged, this, &KIconCanvas::currentListItemChanged);
     setGridSize(QSize(100, 80));
 
     setItemDelegate(m_delegate);
@@ -109,7 +111,7 @@ void KIconCanvas::loadFiles(const QStringList &files)
 {
     clear();
     m_files = files;
-    emit startLoading(m_files.count());
+    Q_EMIT startLoading(m_files.count());
     m_timer->setSingleShot(true);
     m_timer->start(10);
     m_loading = false;
@@ -137,7 +139,7 @@ void KIconCanvas::loadFiles()
     QStringList::ConstIterator end(m_files.constEnd());
     for (it = m_files.constBegin(), i = 0; it != end; ++it, ++i) {
         if (emitProgress >= 10) {
-            emit progress(i);
+            Q_EMIT progress(i);
             emitProgress = 0;
         }
 
@@ -172,7 +174,7 @@ void KIconCanvas::loadFiles()
         }
 
         if (img.width() > canvasIconWidth || img.height() > canvasIconHeight) {
-            if (img.width() / (float)canvasIconWidth  > img.height() / (float)canvasIconHeight) {
+            if (img.width() / (float)canvasIconWidth > img.height() / (float)canvasIconHeight) {
                 int height = (int)(((float)canvasIconWidth / img.width()) * img.height());
                 img = img.scaled(canvasIconWidth, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
             } else {
@@ -203,7 +205,7 @@ void KIconCanvas::loadFiles()
 
     QApplication::restoreOverrideCursor();
     m_loading = false;
-    emit finished();
+    Q_EMIT finished();
     setResizeMode(QListWidget::Adjust);
 }
 
@@ -223,15 +225,20 @@ void KIconCanvas::stopLoading()
 
 void KIconCanvas::currentListItemChanged(QListWidgetItem *item)
 {
-    emit nameChanged((item != nullptr) ? item->text() : QString());
+    Q_EMIT nameChanged((item != nullptr) ? item->text() : QString());
 }
 
 // TODO KF6 remove and override KIconDialog::showEvent()
 class ShowEventFilter : public QObject
 {
 public:
-    explicit ShowEventFilter(QObject *parent) : QObject(parent) {}
-    ~ShowEventFilter() override {}
+    explicit ShowEventFilter(QObject *parent)
+        : QObject(parent)
+    {
+    }
+    ~ShowEventFilter() override
+    {
+    }
 
 private:
     bool eventFilter(QObject *watched, QEvent *event) override
@@ -252,7 +259,8 @@ private:
  */
 
 KIconDialog::KIconDialog(QWidget *parent)
-    : QDialog(parent), d(new KIconDialogPrivate(this))
+    : QDialog(parent)
+    , d(new KIconDialogPrivate(this))
 {
     setModal(true);
     setWindowTitle(i18n("Select Icon"));
@@ -264,7 +272,8 @@ KIconDialog::KIconDialog(QWidget *parent)
 }
 
 KIconDialog::KIconDialog(KIconLoader *loader, QWidget *parent)
-    : QDialog(parent), d(new KIconDialogPrivate(this))
+    : QDialog(parent)
+    , d(new KIconDialogPrivate(this))
 {
     setModal(true);
     setWindowTitle(i18n("Select Icon"));
@@ -275,7 +284,7 @@ KIconDialog::KIconDialog(KIconLoader *loader, QWidget *parent)
     installEventFilter(new ShowEventFilter(this));
 }
 
-void KIconDialog::KIconDialogPrivate::init()
+void KIconDialogPrivate::init()
 {
     mGroupOrSize = KIconLoader::Desktop;
     mContext = KIconLoader::Any;
@@ -293,16 +302,16 @@ void KIconDialog::KIconDialogPrivate::init()
     vbox->addLayout(grid);
 
     mpSystemIcons = new QRadioButton(i18n("S&ystem icons:"), bgroup);
-    connect(mpSystemIcons, SIGNAL(clicked()), q, SLOT(_k_slotSystemIconClicked()));
+    QObject::connect(mpSystemIcons, SIGNAL(clicked()), q, SLOT(_k_slotSystemIconClicked()));
     grid->addWidget(mpSystemIcons, 1, 0);
     mpCombo = new QComboBox(bgroup);
-    connect(mpCombo, SIGNAL(activated(int)), q, SLOT(_k_slotContext(int)));
+    QObject::connect(mpCombo, SIGNAL(activated(int)), q, SLOT(_k_slotContext(int)));
     grid->addWidget(mpCombo, 1, 1);
     mpOtherIcons = new QRadioButton(i18n("O&ther icons:"), bgroup);
-    connect(mpOtherIcons, SIGNAL(clicked()), q, SLOT(_k_slotOtherIconClicked()));
+    QObject::connect(mpOtherIcons, SIGNAL(clicked()), q, SLOT(_k_slotOtherIconClicked()));
     grid->addWidget(mpOtherIcons, 2, 0);
     mpBrowseBut = new QPushButton(i18n("&Browse..."), bgroup);
-    connect(mpBrowseBut, SIGNAL(clicked()), q, SLOT(_k_slotBrowse()));
+    QObject::connect(mpBrowseBut, SIGNAL(clicked()), q, SLOT(_k_slotBrowse()));
     grid->addWidget(mpBrowseBut, 2, 1);
 
     //
@@ -324,7 +333,7 @@ void KIconDialog::KIconDialogPrivate::init()
     searchLine->setWhatsThis(wtstr);
 
     mpCanvas = new KIconCanvas(q);
-    connect(mpCanvas, SIGNAL(itemActivated(QListWidgetItem*)), q, SLOT(_k_slotAcceptIcons()));
+    QObject::connect(mpCanvas, SIGNAL(itemActivated(QListWidgetItem *)), q, SLOT(_k_slotAcceptIcons()));
     top->addWidget(mpCanvas);
     searchLine->setListWidget(mpCanvas);
 
@@ -341,46 +350,41 @@ void KIconDialog::KIconDialogPrivate::init()
 
     mpProgress = new QProgressBar(q);
     top->addWidget(mpProgress);
-    connect(mpCanvas, SIGNAL(startLoading(int)), q, SLOT(_k_slotStartLoading(int)));
-    connect(mpCanvas, SIGNAL(progress(int)), q, SLOT(_k_slotProgress(int)));
-    connect(mpCanvas, SIGNAL(finished()), q, SLOT(_k_slotFinished()));
+    QObject::connect(mpCanvas, SIGNAL(startLoading(int)), q, SLOT(_k_slotStartLoading(int)));
+    QObject::connect(mpCanvas, SIGNAL(progress(int)), q, SLOT(_k_slotProgress(int)));
+    QObject::connect(mpCanvas, SIGNAL(finished()), q, SLOT(_k_slotFinished()));
 
     // When pressing Ok or Cancel, stop loading icons
-    connect(q, &QDialog::finished, mpCanvas, &KIconCanvas::stopLoading);
+    QObject::connect(q, &QDialog::finished, mpCanvas, &KIconCanvas::stopLoading);
 
-    static const char *const context_text[] = {
-        I18N_NOOP("Actions"),
-        I18N_NOOP("Applications"),
-        I18N_NOOP("Categories"),
-        I18N_NOOP("Devices"),
-        I18N_NOOP("Emblems"),
-        I18N_NOOP("Emotes"),
-        I18N_NOOP("Mimetypes"),
-        I18N_NOOP("Places"),
-        I18N_NOOP("Status"),
-        I18N_NOOP("All")
-    };
-    static const KIconLoader::Context context_id[] = {
-        KIconLoader::Action,
-        KIconLoader::Application,
-        KIconLoader::Category,
-        KIconLoader::Device,
-        KIconLoader::Emblem,
-        KIconLoader::Emote,
-        KIconLoader::MimeType,
-        KIconLoader::Place,
-        KIconLoader::StatusIcon,
-        KIconLoader::Any
-    };
+    static const char *const context_text[] = {I18N_NOOP("Actions"),
+                                               I18N_NOOP("Applications"),
+                                               I18N_NOOP("Categories"),
+                                               I18N_NOOP("Devices"),
+                                               I18N_NOOP("Emblems"),
+                                               I18N_NOOP("Emotes"),
+                                               I18N_NOOP("Mimetypes"),
+                                               I18N_NOOP("Places"),
+                                               I18N_NOOP("Status"),
+                                               I18N_NOOP("All")};
+    static const KIconLoader::Context context_id[] = {KIconLoader::Action,
+                                                      KIconLoader::Application,
+                                                      KIconLoader::Category,
+                                                      KIconLoader::Device,
+                                                      KIconLoader::Emblem,
+                                                      KIconLoader::Emote,
+                                                      KIconLoader::MimeType,
+                                                      KIconLoader::Place,
+                                                      KIconLoader::StatusIcon,
+                                                      KIconLoader::Any};
     mNumContext = 0;
-    int cnt = sizeof(context_text) / sizeof(context_text[ 0 ]);
+    int cnt = sizeof(context_text) / sizeof(context_text[0]);
     // check all 3 arrays have same sizes
-    Q_ASSERT(cnt == sizeof(context_id) / sizeof(context_id[ 0 ])
-             && cnt == sizeof(mContextMap) / sizeof(mContextMap[ 0 ]));
+    Q_ASSERT(cnt == sizeof(context_id) / sizeof(context_id[0]) && cnt == sizeof(mContextMap) / sizeof(mContextMap[0]));
     for (int i = 0; i < cnt; ++i) {
-        if (mpLoader->hasContext(context_id[ i ])) {
-            mpCombo->addItem(i18n(context_text[ i ]));
-            mContextMap[ mNumContext++ ] = context_id[ i ];
+        if (mpLoader->hasContext(context_id[i])) {
+            mpCombo->addItem(i18n(context_text[i]));
+            mContextMap[mNumContext++] = context_id[i];
         }
     }
     mpCombo->setMaxVisibleItems(cnt);
@@ -390,8 +394,8 @@ void KIconDialog::KIconDialogPrivate::init()
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(q);
     buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    connect(buttonBox, &QDialogButtonBox::accepted, q, &KIconDialog::slotOk);
-    connect(buttonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
+    QObject::connect(buttonBox, &QDialogButtonBox::accepted, q, &KIconDialog::slotOk);
+    QObject::connect(buttonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
     top->addWidget(buttonBox);
 
     // Make the dialog a little taller
@@ -399,12 +403,9 @@ void KIconDialog::KIconDialogPrivate::init()
     q->adjustSize();
 }
 
-KIconDialog::~KIconDialog()
-{
-    delete d;
-}
+KIconDialog::~KIconDialog() = default;
 
-void KIconDialog::KIconDialogPrivate::_k_slotAcceptIcons()
+void KIconDialogPrivate::_k_slotAcceptIcons()
 {
     custom.clear();
     q->slotOk();
@@ -417,7 +418,7 @@ static bool sortByFileName(const QString &path1, const QString &path2)
     return QString::compare(fileName1, fileName2, Qt::CaseInsensitive) < 0;
 }
 
-void KIconDialog::KIconDialogPrivate::showIcons()
+void KIconDialogPrivate::showIcons()
 {
     mpCanvas->clear();
     QStringList filelist;
@@ -488,9 +489,7 @@ int KIconDialog::iconSize() const
     return (d->mGroupOrSize < 0) ? -d->mGroupOrSize : 0;
 }
 
-void KIconDialog::setup(KIconLoader::Group group, KIconLoader::Context context,
-                        bool strictIconSize, int iconSize, bool user,
-                        bool lockUser, bool lockCustomDir)
+void KIconDialog::setup(KIconLoader::Group group, KIconLoader::Context context, bool strictIconSize, int iconSize, bool user, bool lockUser, bool lockCustomDir)
 {
     d->m_bStrictIconSize = strictIconSize;
     d->m_bLockUser = lockUser;
@@ -517,11 +516,11 @@ void KIconDialog::setup(KIconLoader::Group group, KIconLoader::Context context,
     d->setContext(context);
 }
 
-void KIconDialog::KIconDialogPrivate::setContext(KIconLoader::Context context)
+void KIconDialogPrivate::setContext(KIconLoader::Context context)
 {
     mContext = context;
     for (int i = 0; i < mNumContext; ++i) {
-        if (mContextMap[ i ] == context) {
+        if (mContextMap[i] == context) {
             mpCombo->setCurrentIndex(i);
             return;
         }
@@ -571,13 +570,17 @@ void KIconDialog::slotOk()
         }
     }
 
-    emit newIconName(name);
+    Q_EMIT newIconName(name);
     QDialog::accept();
 }
 
-QString KIconDialog::getIcon(KIconLoader::Group group, KIconLoader::Context context,
-                             bool strictIconSize, int iconSize, bool user,
-                             QWidget *parent, const QString &caption)
+QString KIconDialog::getIcon(KIconLoader::Group group,
+                             KIconLoader::Context context,
+                             bool strictIconSize,
+                             int iconSize,
+                             bool user,
+                             QWidget *parent,
+                             const QString &caption)
 {
     KIconDialog dlg(parent);
     dlg.setup(group, context, strictIconSize, iconSize, user);
@@ -588,7 +591,7 @@ QString KIconDialog::getIcon(KIconLoader::Group group, KIconLoader::Context cont
     return dlg.openDialog();
 }
 
-void KIconDialog::KIconDialogPrivate::_k_slotBrowse()
+void KIconDialogPrivate::_k_slotBrowse()
 {
     if (browseDialog) {
         browseDialog.data()->show();
@@ -601,12 +604,12 @@ void KIconDialog::KIconDialogPrivate::_k_slotBrowse()
     QFileDialog *dlg = new QFileDialog(q, i18n("Select Icon"), QString(), i18n("*.ico *.png *.xpm *.svg *.svgz|Icon Files (*.ico *.png *.xpm *.svg *.svgz)"));
     dlg->setModal(false);
     dlg->setFileMode(QFileDialog::ExistingFile);
-    connect(dlg, SIGNAL(fileSelected(QString)), q, SLOT(_k_customFileSelected(QString)));
+    QObject::connect(dlg, SIGNAL(fileSelected(QString)), q, SLOT(_k_customFileSelected(QString)));
     browseDialog = dlg;
     dlg->show();
 }
 
-void KIconDialog::KIconDialogPrivate::_k_customFileSelected(const QString &path)
+void KIconDialogPrivate::_k_customFileSelected(const QString &path)
 {
     if (!path.isEmpty()) {
         custom = path;
@@ -617,27 +620,27 @@ void KIconDialog::KIconDialogPrivate::_k_customFileSelected(const QString &path)
     }
 }
 
-void KIconDialog::KIconDialogPrivate::_k_slotSystemIconClicked()
+void KIconDialogPrivate::_k_slotSystemIconClicked()
 {
     mpBrowseBut->setEnabled(false);
     mpCombo->setEnabled(true);
     showIcons();
 }
 
-void KIconDialog::KIconDialogPrivate::_k_slotOtherIconClicked()
+void KIconDialogPrivate::_k_slotOtherIconClicked()
 {
     mpBrowseBut->setEnabled(!m_bLockCustomDir);
     mpCombo->setEnabled(false);
     showIcons();
 }
 
-void KIconDialog::KIconDialogPrivate::_k_slotContext(int id)
+void KIconDialogPrivate::_k_slotContext(int id)
 {
-    mContext = static_cast<KIconLoader::Context>(mContextMap[ id ]);
+    mContext = static_cast<KIconLoader::Context>(mContextMap[id]);
     showIcons();
 }
 
-void KIconDialog::KIconDialogPrivate::_k_slotStartLoading(int steps)
+void KIconDialogPrivate::_k_slotStartLoading(int steps)
 {
     if (steps < 10) {
         mpProgress->hide();
@@ -648,12 +651,12 @@ void KIconDialog::KIconDialogPrivate::_k_slotStartLoading(int steps)
     }
 }
 
-void KIconDialog::KIconDialogPrivate::_k_slotProgress(int p)
+void KIconDialogPrivate::_k_slotProgress(int p)
 {
     mpProgress->setValue(static_cast<int>(100.0 * (double)p / (double)mNumOfSteps));
 }
 
-void KIconDialog::KIconDialogPrivate::_k_slotFinished()
+void KIconDialogPrivate::_k_slotFinished()
 {
     mNumOfSteps = 1;
     mpProgress->hide();
